@@ -115,8 +115,8 @@ sub run {
               "at line $line";
         }
         my $changes = Parse::DebianChangelog->init({
-                infile => $dnews,
-                quiet => 1,
+            infile => $dnews,
+            quiet => 1,
         });
         if (my @errors = $changes->get_parse_errors) {
             for (@errors) {
@@ -323,7 +323,7 @@ sub run {
             my $first_dist = lc $entries[0]->Distribution;
             my $second_dist = lc $entries[1]->Distribution;
             if ($first_dist eq 'unstable' and $second_dist eq 'experimental') {
-                unless ($entries[0]->Changes =~ /\bto\s+unstable\b/) {
+                unless ($entries[0]->Changes =~ /\bto\s+(?:unstable|sid)\b/im){
                     tag 'experimental-to-unstable-without-comment';
                 }
             }
