@@ -306,7 +306,8 @@ my @file_checks = (
 our @EOL_TERMINATORS_FILES = qw(control changelog);
 
 sub run {
-    my (undef, undef, $info) = @_;
+    my (undef, undef, $info, $proc) = @_;
+    my $source_pkg = $proc->pkg_src;
     my $droot = $info->debfiles;
 
     if (-e "$droot/files" and not -z "$droot/files") {
@@ -353,7 +354,7 @@ sub run {
     }elsif (not $info->native) {
         check_diffstat($info->diffstat, \%warned);
     }
-    find_cruft($info, \%warned, $atdinbd, $ltinbd);
+    find_cruft($source_pkg, $info, \%warned, $atdinbd, $ltinbd);
 
     for my $file (@EOL_TERMINATORS_FILES) {
         my $path = $info->debfiles($file);
@@ -507,7 +508,7 @@ sub check_debfiles {
 # "source-contains" tag.  The tag isn't entirely accurate, but it's better
 # than creating yet a third set of tags, and this gets the severity right.
 sub find_cruft {
-    my ($info, $warned, $atdinbd, $ltinbd) = @_;
+    my ($source_pkg, $info, $warned, $atdinbd, $ltinbd) = @_;
     my $prefix = ($info->native ? 'diff-contains' : 'source-contains');
     my @worklist;
 
@@ -518,6 +519,7 @@ sub find_cruft {
     while (my $entry = shift(@worklist)) {
         my $name     = $entry->name;
         my $basename = $entry->basename;
+        my $dirname = $entry->dirname;
         my $path;
         my $file_info;
 
@@ -596,8 +598,8 @@ sub find_cruft {
                 if($name =~ m{$regname}) {
                     tag $tag_filetype, $name;
                     if($warn_data->{'checkmissing'}) {
-                        check_missing_source($entry,$info,
-                            $warn_data->{'transform'});
+                        check_missing_source($entry,$info,$name, $basename,
+                            $dirname,$warn_data->{'transform'});
                     }
                 }
             }
@@ -635,7 +637,7 @@ sub find_cruft {
         # debian/config.cache as anyone doing that probably knows what
         # they're doing and is using it as part of the build.
         if ($basename =~ m{\A config.(?:cache|log|status) \Z}xsm) {
-            if ($entry->dirname ne 'debian') {
+            if ($dirname ne 'debian') {
                 tag 'configure-generated-file-in-source', $name;
             }
         }elsif ($basename =~ m{\A config.(?:guess|sub) \Z}xsm
@@ -677,14 +679,15 @@ sub find_cruft {
             }
             close($fd);
         }
-        full_text_check($entry, $info, $name, $info->unpacked($entry));
+        full_text_check($source_pkg, $entry, $info, $name, $basename, $dirname,
+            $info->unpacked($entry));
     }
     return;
 }
 
 # try to check if source is missing
 sub check_missing_source {
-    my ($file, $info, $replacementspairref) = @_;
+    my ($file, $info, $name, $basename, $dirname,$replacementspairref) = @_;
 
     # do not check missing source for non free
     if($info->is_non_free) {
@@ -700,10 +703,6 @@ sub check_missing_source {
         return;
     }
 
-    my $basename = $file->basename;
-    my $dirname = $file->dirname;
-    my $name = $file->name;
-
     # try to find for each replacement
   REPLACEMENT:
     foreach my $pair (@replacementspair) {
@@ -714,7 +713,7 @@ sub check_missing_source {
         if($match eq '') {
             $newbasename = $basename;
         } else {
-            $newbasename =~ s/$match/$replace/g;
+            $newbasename =~ s/$match/$replace/;
         }
         # next but we may be return an error
         if($newbasename eq '') {
@@ -757,7 +756,7 @@ sub check_missing_source {
 # note that it does not replace licensecheck(1)
 # and is only used for autoreject by ftp-master
 sub full_text_check {
-    my ($entry, $info, $name, $path) = @_;
+    my ($source_pkg, $entry, $info, $name, $basename, $dirname, $path) = @_;
 
     # license string in debian/changelog are probably just change
     # Ignore these strings in d/README.{Debian,source}.  If they
@@ -769,12 +768,6 @@ sub full_text_check {
         return;
     }
 
-    my $isjsfile = ($name =~ m/\.js$/) ? 1 : 0;
-    if($isjsfile) {
-        my $minjsregexp =  _minified_javascript_name_regexp();
-        $isjsfile = ($name =~ m{$minjsregexp}) ? 0 : 1;
-    }
-
     open(my $fd, '<:raw', $path);
     # allow to check only text file
     unless (-T $fd) {
@@ -784,7 +777,8 @@ sub full_text_check {
 
     # some js file comments are really really long
     my $sfd
-      = Lintian::SlidingWindow->new($fd, \&lc_block,$isjsfile ? 8092 : 4096);
+      = Lintian::SlidingWindow->new($fd, \&lc_block,
+        _is_javasript_but_not_minified($name) ? 8092 : 4096);
     my %licenseproblemhash;
 
     # we try to read this file in block and use a sliding window
@@ -798,9 +792,8 @@ sub full_text_check {
 
         if(
             _license_check(
-                $name, $NON_DISTRIBUTABLE_LICENSES,
-                $block,  $blocknumber,
-                \$cleanedblock, \%matchedkeyword,
+                $source_pkg, $name,$NON_DISTRIBUTABLE_LICENSES,$block,
+                $blocknumber,\$cleanedblock,\%matchedkeyword,
                 \%licenseproblemhash
             )
           ){
@@ -813,41 +806,86 @@ sub full_text_check {
             next BLOCK;
         }
 
-        _license_check($name, $NON_FREE_LICENSES,
+        _license_check($source_pkg, $name, $NON_FREE_LICENSES,
             $block,  $blocknumber,\$cleanedblock, \%matchedkeyword,
             \%licenseproblemhash);
 
-        # check javascript  problem
-        if($isjsfile) {
-            if($blocknumber == 0) {
-                my $strip = $block;
-                # from perl faq strip comments
-                $strip
-                  =~ s#/\*[^*]*\*+([^/*][^*]*\*+)*/|//([^\\]|[^\n][\n]?)*?\n|("(\\.|[^"\\])*"|'(\\.|[^'\\])*'|.[^/"'\\]*)#defined $3 ? $3 : ""#gse;
-                # strip empty line
-                $strip =~ s/^\s*\n//mg;
-                # remove last \n
-                $strip =~ s/\n\Z//m;
-                # compute now means line length
-                my $total = length($strip);
-                if($total > 0) {
-                    my $linelength = $total/($strip =~ tr/\n// + 1);
-                    if($linelength > 255) {
-                        tag 'source-contains-prebuilt-javascript-object',
-                          $name, 'mean line length is about', int($linelength),
-                          'characters';
-                        # Check for missing source.  It will check
-                        # for the source file in well known directories
-                        check_missing_source($entry,$info,[['','']]);
-                    }
-                }
-            }
+        # check only in block 0
+        if($blocknumber == 0) {
+            _search_in_block0($entry, $info, $name, $basename, $dirname,
+                $path, $block);
         }
     }
     close($fd);
     return;
 }
 
+# check if file is javascript but not minified
+sub _is_javasript_but_not_minified {
+    my ($name) = @_;
+    my $isjsfile = ($name =~ m/\.js$/) ? 1 : 0;
+    if($isjsfile) {
+        my $minjsregexp =  _minified_javascript_name_regexp();
+        $isjsfile = ($name =~ m{$minjsregexp}) ? 0 : 1;
+    }
+    return $isjsfile;
+}
+
+# search something in block $0
+sub _search_in_block0 {
+    my ($entry, $info, $name, $basename, $dirname, $path, $block) = @_;
+
+    if(_is_javasript_but_not_minified($name)) {
+        # exception sphinx documentation
+        if($basename eq 'searchindex.js') {
+            if($block =~ m/\A\s*search\.setindex\s* \s* \(\s*\{/xms) {
+                tag 'source-contains-prebuilt-sphinx-documentation', $dirname;
+                return;
+            }
+        }
+        # see #745152
+        # Be robust check also .js
+        if($basename eq 'deployJava.js') {
+            if($block =~ m/(?:\A|\v)\s*var\s+deployJava\s*=\s*function/xmsi) {
+                check_missing_source($entry,$info,$name,$basename,$dirname,
+                    [['(?i)\.js$','.txt'],['','']]);
+            }
+        }
+        # now search hidden minified
+        _linelength_test($entry, $info, $name, $basename, $dirname,
+            $path, $block);
+    }
+    return;
+}
+
+# try to detect non human source based on line length
+sub _linelength_test {
+    my ($entry, $info, $name, $basename, $dirname, $path, $block) = @_;
+    my $strip = $block;
+    # from perl faq strip comments
+    $strip
+      =~ s#/\*[^*]*\*+([^/*][^*]*\*+)*/|//([^\\]|[^\n][\n]?)*?(?=\n)|("(\\.|[^"\\])*"|'(\\.|[^'\\])*'|.[^/"'\\]*)#defined $3 ? $3 : ""#gse;
+    # strip empty line
+    $strip =~ s/^\s*\n//mg;
+    # remove last \n
+    $strip =~ s/\n\Z//m;
+    # compute now means line length
+    my $total = length($strip);
+    if($total > 0) {
+        my $linelength = $total/($strip =~ tr/\n// + 1);
+        if($linelength > 255) {
+            tag 'source-contains-prebuilt-javascript-object',
+              $name, 'mean line length is about', int($linelength),
+              'characters';
+            # Check for missing source.  It will check
+            # for the source file in well known directories
+            check_missing_source($entry,$info,$name,$basename,$dirname,
+                [['','']]);
+        }
+    }
+    return;
+}
+
 sub _tag_gfdl {
     my ($applytag, $name, $gfdlsections) = @_;
     tag $applytag, $name, 'invariant part is:', $gfdlsections;
@@ -868,11 +906,16 @@ sub _check_gfdl_license_problem {
 
     # remove classical and without meaning part of
     # matched string
-    $gfdlsections =~ s{
-                          \A version [ ] \d+(?:\.\d+)? [ ]
-                           (?:or [ ] any [ ] later [ ] version [ ])?
-                           published [ ] by [ ] the [ ] free [ ] software [ ] foundation
-                           [ ]?[,\.;]?[ ]?}{}xismo;
+    $gfdlsections =~ s{ \A \(?[ ]? g?fdl [ ]?\)?[ ]? [,\.;]?[ ]?}{}xismo;
+    $gfdlsections =~ s{ \A (?:either[ ])?
+                           version [ ] \d+(?:\.\d+)? [ ]?}{}xismo;
+    $gfdlsections =~ s{ \A of [ ] the [ ] license [ ]?[,\.;][ ]?}{}xismo;
+    $gfdlsections =~ s{ \A or (?:[ ]\(?[ ]? at [ ] your [ ] option [ ]?\)?)?
+                           [ ] any [ ] later [ ] version[ ]?}{}xismo;
+    $gfdlsections =~ s{ \A published [ ] by [ ]
+                           the [ ] free [ ] software [ ] foundation[ ]?}{}xismo;
+    $gfdlsections =~ s{\(?[ ]?FSF[ ]?\)?[ ]?}{}xismo;
+    $gfdlsections =~ s{[,\.;]?[ ]?}{}xismo;
     $contextbefore =~ s{
                           [ ]? (:?[,\.;]? [ ]?)?
                            permission [ ] is [ ] granted [ ] to [ ] copy [ ]?[,\.;]?[ ]?
@@ -960,40 +1003,85 @@ sub _clean_block {
     $text =~ s{ \\ -}{-}gxsm;
 
     # replace some common comment-marker/markup with space
-    $text =~ s{(?:
-                  ^\.\\\"                      |  # man comments
-                  \@c(?:omment)?\s+            |  # Tex info comment
-                  \@(?:b|i|r|t)\{              |  # Tex info bold, italic, roman, fixed width
-                  \@(?:sansserif|slanted)\{    |  # Tex info sans serif/slanted
-                  \@var\{                      |  # Tex info emphasis
-                  \@(?:small)?example\s+       |  # Tex info example
-                  \@end\h+(?:small)example\s+  |  # Tex info end small example tag
-                  \@group\s+                   |  # Tex info group
-                  \@end\h+group\s+             |  # Tex info end group
-                  \}                           |  # Tex info end tag (could be more clever but brute force is fast)
-                  \"\s*,                       |  # String array (e.g. "line1",\n"line2")
-                  ,\s*\"                       |  # String array (e.g. "line1"\n ,"line2"), seen in findutils
-                  <br\s*/?>                    |  # (X)HTML line breaks
-                  <!--                         |  # XML comment
-                  -->                          |  # end XML comment
-                  </?link[^>]*?>               |  # xml link
-                  </?a[^>]*?>                  |  # a link
-                  </?citetitle[^>]*?>          |  # citation title in docbook
-                  </?div[^>]*?>                |  # html style
-                  </?p[^>]*?>                  |  # html paragraph
-                  </?span[^>]*?>               |  # span tag
-                  </?var[^>]*?>                |  # var tag used by html from texinfo
-                  ^[-\+!<>]                    |  # diff/patch lines (should be after html tag)
-                  \(\*note.*?::\)              |  # info file note
-                  \\n                          |  # Verbatim \n in string array
-                  \\&                          |  # pod2man formating
-                  \\s(?:0|-1)                  |  # pod2man formating
-                  (?:``|'')                    |  # quote like
-                  [%\*\"\|\\\#]                   # String, C-style comment/javadoc indent,
-                                                  # quotes for strings, pipe and antislash in some txt
-                                                  # shell or po file comments
-           )}{ }gxms;
+    $text =~ s{^\.\\\"}{ }gxms;               # man comments
 
+    # po comment may include html tag
+    $text =~ s/\"\s?\v\#~\s?\"//gxms;
+
+    $text =~ s/\\url{[^}]*?}/ /gxms;          # (la)?tex url
+    $text =~ s/\emph{/ /gxms;                 # (la)?tex emph
+    $text =~ s/\\href{[^}]*?}
+                     {([^}]*?)}/ $1 /gxms;    # (la)?tex href
+    $text =~ s/\\hyperlink
+                 {[^}]*?}{([^}]*?)}/ $1 /gxms;# (la)?tex hyperlink
+    $text =~ s,-\\/,-,gxms;                   # tex strange hyphen
+    $text =~ s,\\char, ,gxms;                 # tex  char command
+
+    # Tex info comment with end section
+    $text =~ s/\@c(?:omment)?\h+
+                end \h+ ifman\s+/ /gxms;
+    $text =~ s/\@c(?:omment)?\s+
+                noman\s+/ /gxms;              # Tex info comment no manual
+
+    $text =~ s/\@c(?:omment)?\s+/ /gxms;      # Tex info comment
+
+    # Tex info bold,italic, roman, fixed width
+    $text =~ s/\@[birt]{/ /gxms;
+    $text =~ s/\@sansserif{/ /gxms;           # Tex info sans serif
+    $text =~ s/\@slanted{/ /gxms;             # Tex info slanted
+    $text =~ s/\@var{/ /gxms;                 # Tex info emphasis
+
+    $text =~ s/\@(?:small)?example\s+/ /gxms; # Tex info example
+    $text =~ s/\@end \h+
+               (?:small)example\s+/ /gxms;    # Tex info end example tag
+    $text =~ s/\@group\s+/ /gxms;             # Tex info group
+    $text =~ s/\@end\h+group\s+/ /gxms;       # Tex info end group
+
+    $text =~ s/<!--/ /gxms;                   # XML comments
+    $text =~ s/-->/ /gxms;                    # end XML comment
+
+    $text =~ s{</?a[^>]*?>}{ }gxms;           # a link
+    $text =~ s{<br\s*/?>}{ }gxms;             # (X)?HTML line
+    # breaks
+    $text =~ s{</?citetitle[^>]*?>}{ }gxms;   # docbook citation title
+    $text =~ s{</?div[^>]*?>}{ }gxms;         # html style
+    $text =~ s{</?font[^>]*?>}{ }gxms;        # font
+    $text =~ s{</?i[^>]*?>}{ }gxms;           # italic
+    $text =~ s{</?link[^>]*?>}{ }gxms;        # xml link
+    $text =~ s{</?p[^>]*?>}{ }gxms;           # html paragraph
+    $text =~ s{</?quote[^>]*?>}{ }gxms;       # xml quote
+    $text =~ s{</?span[^>]*?>}{ }gxms;        # span tag
+    $text =~ s{</?ulink[^>]*?>}{ }gxms;       # ulink docbook
+    $text =~ s{</?var[^>]*?>}{ }gxms;         # var used by texinfo2html
+
+    $text =~ s{\&[lr]dquo;}{ }gxms;           # html rquote
+
+    $text =~ s{\(\*note.*?::\)}{ }gxms;       # info file note
+
+    # String array (e.g. "line1",\n"line2")
+    $text =~ s/\"\s*,/ /gxms;
+    # String array (e.g. "line1"\n ,"line2"),
+    $text =~ s/,\s*\"/ /gxms;
+    $text =~ s/\\n/ /gxms;                    # Verbatim \n in string array
+
+    $text =~ s/\\&/ /gxms;                    # pod2man formating
+    $text =~ s/\\s(?:0|-1)/ /gxms;            # pod2man formating
+
+    $text =~ s/(?:``|'')/ /gxms;              # quote like
+
+    # diff/patch lines (should be after html tag)
+    $text =~ s/^[-\+!<>]/ /gxms;
+    $text =~ s/\@\@ \s*
+               [-+] \d+,\d+ \s+
+               [-+] \d+,\d+ \s*
+               \@\@/ /gxms;                   # patch line
+
+    # Tex info end tag (could be more clever but brute force is fast)
+    $text =~ s/}/ /gxms;
+    # single char at end
+    # String, C-style comment/javadoc indent,
+    # quotes for strings, pipe and antislash, tilde in some txt
+    $text =~ s,[%\*\"\|\\\#~], ,gxms;
     # delete double spacing now and normalize spacing
     # to space character
     $text =~ s{\s++}{ }gsm;
@@ -1041,10 +1129,15 @@ sub _md5sum_based_check {
 
 # check bad license
 sub _license_check {
-    my ($name, $licensesdatas, $block, $blocknumber, $cleanedblock,
-        $matchedkeyword, $licenseproblemhash)
+    my ($source_pkg, $name, $licensesdatas, $block, $blocknumber,
+        $cleanedblock,$matchedkeyword, $licenseproblemhash)
       = @_;
     my $ret = 0;
+
+    # avoid to check lintian
+    if($source_pkg eq 'lintian') {
+        return $ret;
+    }
   LICENSE:
     foreach my $licenseproblem ($licensesdatas->all) {
         my $licenseproblemdata = $licensesdatas->value($licenseproblem);
